@@ -313,6 +313,7 @@ class WorkflowHandle(Base):
     # the workflow and all dependend runs.
     postproc_run_id = Column(String(32), nullable=True)
     postproc_spec = Column(JsonObject)
+    ignore_postproc = Column(Boolean, nullable=False, default=False)
     result_schema = Column(WorkflowResultSchema)
 
     # -- Relationships --------------------------------------------------------
@@ -367,6 +368,19 @@ class WorkflowHandle(Base):
         ranking = sorted(self.postproc_ranking, key=lambda r: r.rank)
         return [r.run_id for r in ranking]
 
+    @property
+    def run_postproc(self):
+        """Returns True iff the result schema and post-processing workflow are
+        defined and the ignore_postproc flag is False.
+
+        Returns
+        -------
+        bool
+        """
+        has_schema = self.result_schema is not None
+        has_postproc = self.postproc_spec is not None
+        return has_schema and has_postproc and not self.ignore_postproc
+
 
 # -- Workflow Groups ----------------------------------------------------------
 
@@ -569,9 +583,11 @@ class RunHandle(Base):
         return self.state_type == st.STATE_SUCCESS
 
     def outputs(self):
-        """Get specification of output file properties. If the workflow
-        template does not contain any output file specifications the result
-        is None.
+        """Get specification of output file properties. The result is a
+        dictionary of workflow output file specifications keyed by either the
+        user-specified key or the file source. If the workflow template does
+        not contain any output file specifications the result is an empty
+        dictionary.
 
         If the run is associated with a group, then the output file
         specification of the associated workflow is returned. If the run is a
@@ -580,15 +596,27 @@ class RunHandle(Base):
 
         Returns
         -------
-        list(flowserv.model.template.files.WorkflowOutputFile)
+        dict(string: flowserv.model.template.files.WorkflowOutputFile)
         """
         if self.group_id is not None:
-            return self.workflow.outputs
+            # The run is for a workflow group submission.
+            outputs = self.workflow.outputs
         else:
+            # The run was for a ppst-processing workflow. In this case the
+            # postproc sepecification will contain the output file definitions
+            # that we are interested in.
             outputs = self.workflow.postproc_spec.get('outputs')
             if outputs is not None:
                 outputs = [WorkflowOutputFile.from_dict(f) for f in outputs]
-            return outputs
+        # Return an empty dictionary if no output specification was found.
+        if not outputs:
+            return dict()
+        # Create dictionary that maps user-defined key or file source to the
+        # workflow output file specifications.
+        result = dict()
+        for f in outputs:
+            result[f.source] = f
+        return result
 
     def state(self):
         """Get an instance of the workflow state for the given run.
